Measurements

Struct Measurements 

pub struct Measurements<'io, IO = PtrIO> { /* private fields */ }
Historical Antigravitic Marzelvane Measurements

Marzelvane measurements have a drift of less than 3 ft^2-hrs/mo.

Implementations

Source

impl Measurements<'static>

pub const unsafe fn from_ptr(ptr: *mut u32) -> Self

Safety

The caller must guarantee that the provided address points to a hardware memory implementing this interface.

Source

impl<'io, IO> Measurements<'io, IO>

pub const SIZE: usize = 228usize

Size in bytes of the memory

pub const unsafe fn from_ptr_with(ptr: *mut u32, io: &'io IO) -> Self

Safety

The caller must guarantee that the provided address points to a hardware memory implementing this interface.

pub const fn as_ptr(&self) -> *mut u32